# Device Configuration

For device and parallelism configuration, see [DeviceParameters](parameters.md#deviceparameters) in the main configuration documentation.

Key topics covered:
- Single device training
- FSDP (Fully Sharded Data Parallel)
- HSDP (Hybrid Sharded Data Parallel)  
- DDP (Distributed Data Parallel)
- Tensor parallelism
- Pipeline parallelism
- Mixed precision settings
- Model compilation options 